types

package
v1.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 18, 2025 License: Apache-2.0 Imports: 33 Imported by: 0

Documentation

Overview

Package types is a reverse proxy.

It translates gRPC into RESTful JSON APIs.

Index

Constants

const (
	// ModuleName defines the module name
	ModuleName = "billing"

	// StoreKey defines the primary module store key
	StoreKey = ModuleName

	// RouterKey defines the module's message routing key
	RouterKey = ModuleName

	// MemStoreKey defines the in-memory store key
	MemStoreKey = "mem_billing"

	AttributeKeyAccount = "account"
	AttributeKeyAmount  = "amount"
	AttributeKeyMemo    = "memo"
)
const DefaultIndex uint64 = 1

DefaultIndex is the default global index

const SAGA_EPOCH_IDENTIFIER string = "day"

Variables

var (
	ErrInvalidLengthBillingHistory        = fmt.Errorf("proto: negative length found during unmarshaling")
	ErrIntOverflowBillingHistory          = fmt.Errorf("proto: integer overflow")
	ErrUnexpectedEndOfGroupBillingHistory = fmt.Errorf("proto: unexpected end of group")
)
var (
	ErrInternalFailure        = cosmossdkerrors.Register(ModuleName, 7700, "internal failure")
	ErrNoRecords              = cosmossdkerrors.Register(ModuleName, 7701, "no records found")
	ErrJSONMarhsal            = cosmossdkerrors.Register(ModuleName, 7702, "failed to marshal json")
	ErrDuplicateRecord        = cosmossdkerrors.Register(ModuleName, 7703, "duplicate record")
	ErrInternalBillingFailure = cosmossdkerrors.Register(ModuleName, 7704, "internal failure")
	ErrUnauthorized           = cosmossdkerrors.Register(ModuleName, 7705, "unauthorized")
)
var (
	ErrInvalidLengthEvents        = fmt.Errorf("proto: negative length found during unmarshaling")
	ErrIntOverflowEvents          = fmt.Errorf("proto: integer overflow")
	ErrUnexpectedEndOfGroupEvents = fmt.Errorf("proto: unexpected end of group")
)
var (
	ErrInvalidLengthGenesis        = fmt.Errorf("proto: negative length found during unmarshaling")
	ErrIntOverflowGenesis          = fmt.Errorf("proto: integer overflow")
	ErrUnexpectedEndOfGroupGenesis = fmt.Errorf("proto: unexpected end of group")
)
var (
	BillingHistoryKey         = "billinghistory"
	ValidatorPayoutHistoryKey = "validatorpayout"
)
var (
	ErrInvalidLengthParams        = fmt.Errorf("proto: negative length found during unmarshaling")
	ErrIntOverflowParams          = fmt.Errorf("proto: integer overflow")
	ErrUnexpectedEndOfGroupParams = fmt.Errorf("proto: unexpected end of group")
)
var (
	ErrInvalidLengthQuery        = fmt.Errorf("proto: negative length found during unmarshaling")
	ErrIntOverflowQuery          = fmt.Errorf("proto: integer overflow")
	ErrUnexpectedEndOfGroupQuery = fmt.Errorf("proto: unexpected end of group")
)
var (
	ErrInvalidLengthSaveBillingHistory        = fmt.Errorf("proto: negative length found during unmarshaling")
	ErrIntOverflowSaveBillingHistory          = fmt.Errorf("proto: integer overflow")
	ErrUnexpectedEndOfGroupSaveBillingHistory = fmt.Errorf("proto: unexpected end of group")
)
var (
	ErrInvalidLengthTx        = fmt.Errorf("proto: negative length found during unmarshaling")
	ErrIntOverflowTx          = fmt.Errorf("proto: integer overflow")
	ErrUnexpectedEndOfGroupTx = fmt.Errorf("proto: unexpected end of group")
)
var (
	ErrInvalidLengthValidatorPayoutHistory        = fmt.Errorf("proto: negative length found during unmarshaling")
	ErrIntOverflowValidatorPayoutHistory          = fmt.Errorf("proto: integer overflow")
	ErrUnexpectedEndOfGroupValidatorPayoutHistory = fmt.Errorf("proto: unexpected end of group")
)
var Msg_serviceDesc = _Msg_serviceDesc
var Query_serviceDesc = _Query_serviceDesc

Functions

func KeyPrefix

func KeyPrefix(p string) []byte

func ParamKeyTable

func ParamKeyTable() paramtypes.KeyTable

ParamKeyTable the param key table for launch module

func RegisterCodec

func RegisterCodec(cdc *codec.LegacyAmino)

func RegisterInterfaces

func RegisterInterfaces(registry cdctypes.InterfaceRegistry)

func RegisterMsgServer

func RegisterMsgServer(s grpc1.Server, srv MsgServer)

func RegisterQueryHandler

func RegisterQueryHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error

RegisterQueryHandler registers the http handlers for service Query to "mux". The handlers forward requests to the grpc endpoint over "conn".

func RegisterQueryHandlerClient

func RegisterQueryHandlerClient(ctx context.Context, mux *runtime.ServeMux, client QueryClient) error

RegisterQueryHandlerClient registers the http handlers for service Query to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "QueryClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "QueryClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "QueryClient" to call the correct interceptors.

func RegisterQueryHandlerFromEndpoint

func RegisterQueryHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)

RegisterQueryHandlerFromEndpoint is same as RegisterQueryHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.

func RegisterQueryHandlerServer

func RegisterQueryHandlerServer(ctx context.Context, mux *runtime.ServeMux, server QueryServer) error

RegisterQueryHandlerServer registers the http handlers for service Query to "mux". UnaryRPC :call QueryServer directly. StreamingRPC :currently unsupported pending https://github.com/grpc/grpc-go/issues/906. Note that using this registration option will cause many gRPC library features to stop working. Consider using RegisterQueryHandlerFromEndpoint instead.

func RegisterQueryServer

func RegisterQueryServer(s grpc1.Server, srv QueryServer)

Types

type AccountKeeper

type AccountKeeper interface {
	GetAccount(ctx context.Context, addr sdk.AccAddress) sdk.AccountI
	GetModuleAccount(ctx context.Context, moduleName string) sdk.ModuleAccountI
}

AccountKeeper defines the expected account keeper used for simulations (noalias)

type BankKeeper

type BankKeeper interface {
	SpendableCoins(ctx context.Context, addr sdk.AccAddress) sdk.Coins
	ValidateBalance(ctx context.Context, addr sdk.AccAddress) error
	HasBalance(ctx context.Context, addr sdk.AccAddress, amt sdk.Coin) bool

	GetAllBalances(ctx context.Context, addr sdk.AccAddress) sdk.Coins
	GetAccountsBalances(ctx context.Context) []banktypes.Balance
	GetBalance(ctx context.Context, addr sdk.AccAddress, denom string) sdk.Coin
	LockedCoins(ctx context.Context, addr sdk.AccAddress) sdk.Coins

	IterateAccountBalances(ctx context.Context, addr sdk.AccAddress, cb func(coin sdk.Coin) (stop bool))
	IterateAllBalances(ctx context.Context, cb func(address sdk.AccAddress, coin sdk.Coin) (stop bool))

	SendCoinsFromModuleToAccount(ctx context.Context, senderModule string, recipientAddr sdk.AccAddress, amt sdk.Coins) error
	SendCoinsFromModuleToModule(ctx context.Context, senderModule, recipientModule string, amt sdk.Coins) error
	SendCoinsFromAccountToModule(ctx context.Context, senderAddr sdk.AccAddress, recipientModule string, amt sdk.Coins) error
}

BankKeeper defines the expected interface needed to retrieve account balances.

type BillingEvent

type BillingEvent struct {
	// option (gogoproto.goproto_stringer) = false;
	ChainId string `protobuf:"bytes,1,opt,name=chainId,proto3" json:"chainId,omitempty"`
	Amount  string `protobuf:"bytes,2,opt,name=amount,proto3" json:"amount,omitempty"`
	Memo    string `protobuf:"bytes,3,opt,name=memo,proto3" json:"memo,omitempty"`
	Success bool   `protobuf:"varint,4,opt,name=success,proto3" json:"success,omitempty"`
	Debit   bool   `protobuf:"varint,5,opt,name=debit,proto3" json:"debit,omitempty"`
}

func (*BillingEvent) Descriptor

func (*BillingEvent) Descriptor() ([]byte, []int)

func (*BillingEvent) GetAmount

func (m *BillingEvent) GetAmount() string

func (*BillingEvent) GetChainId

func (m *BillingEvent) GetChainId() string

func (*BillingEvent) GetDebit

func (m *BillingEvent) GetDebit() bool

func (*BillingEvent) GetMemo

func (m *BillingEvent) GetMemo() string

func (*BillingEvent) GetSuccess

func (m *BillingEvent) GetSuccess() bool

func (*BillingEvent) Marshal

func (m *BillingEvent) Marshal() (dAtA []byte, err error)

func (*BillingEvent) MarshalTo

func (m *BillingEvent) MarshalTo(dAtA []byte) (int, error)

func (*BillingEvent) MarshalToSizedBuffer

func (m *BillingEvent) MarshalToSizedBuffer(dAtA []byte) (int, error)

func (*BillingEvent) ProtoMessage

func (*BillingEvent) ProtoMessage()

func (*BillingEvent) Reset

func (m *BillingEvent) Reset()

func (*BillingEvent) Size

func (m *BillingEvent) Size() (n int)

func (*BillingEvent) String

func (m *BillingEvent) String() string

func (*BillingEvent) Unmarshal

func (m *BillingEvent) Unmarshal(dAtA []byte) error

func (*BillingEvent) XXX_DiscardUnknown

func (m *BillingEvent) XXX_DiscardUnknown()

func (*BillingEvent) XXX_Marshal

func (m *BillingEvent) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*BillingEvent) XXX_Merge

func (m *BillingEvent) XXX_Merge(src proto.Message)

func (*BillingEvent) XXX_Size

func (m *BillingEvent) XXX_Size() int

func (*BillingEvent) XXX_Unmarshal

func (m *BillingEvent) XXX_Unmarshal(b []byte) error

type BillingHistory

type BillingHistory struct {
	ChainletOwner     string `protobuf:"bytes,1,opt,name=chainletOwner,proto3" json:"chainletOwner,omitempty"`
	ChainletName      string `protobuf:"bytes,2,opt,name=chainletName,proto3" json:"chainletName,omitempty"`
	ChainletId        string `protobuf:"bytes,3,opt,name=chainletId,proto3" json:"chainletId,omitempty"`
	ChainletStackName string `protobuf:"bytes,4,opt,name=chainletStackName,proto3" json:"chainletStackName,omitempty"`
	EpochIdentifier   string `protobuf:"bytes,5,opt,name=epochIdentifier,proto3" json:"epochIdentifier,omitempty"`
	EpochNumber       int64  `protobuf:"varint,6,opt,name=epochNumber,proto3" json:"epochNumber,omitempty"`
	EpochStartTime    string `protobuf:"bytes,7,opt,name=epochStartTime,proto3" json:"epochStartTime,omitempty"`
	BilledAmount      string `protobuf:"bytes,8,opt,name=billedAmount,proto3" json:"billedAmount,omitempty"`
}

func (*BillingHistory) Descriptor

func (*BillingHistory) Descriptor() ([]byte, []int)

func (*BillingHistory) GetBilledAmount

func (m *BillingHistory) GetBilledAmount() string

func (*BillingHistory) GetChainletId

func (m *BillingHistory) GetChainletId() string

func (*BillingHistory) GetChainletName

func (m *BillingHistory) GetChainletName() string

func (*BillingHistory) GetChainletOwner

func (m *BillingHistory) GetChainletOwner() string

func (*BillingHistory) GetChainletStackName

func (m *BillingHistory) GetChainletStackName() string

func (*BillingHistory) GetEpochIdentifier

func (m *BillingHistory) GetEpochIdentifier() string

func (*BillingHistory) GetEpochNumber

func (m *BillingHistory) GetEpochNumber() int64

func (*BillingHistory) GetEpochStartTime

func (m *BillingHistory) GetEpochStartTime() string

func (*BillingHistory) Marshal

func (m *BillingHistory) Marshal() (dAtA []byte, err error)

func (*BillingHistory) MarshalTo

func (m *BillingHistory) MarshalTo(dAtA []byte) (int, error)

func (*BillingHistory) MarshalToSizedBuffer

func (m *BillingHistory) MarshalToSizedBuffer(dAtA []byte) (int, error)

func (*BillingHistory) ProtoMessage

func (*BillingHistory) ProtoMessage()

func (*BillingHistory) Reset

func (m *BillingHistory) Reset()

func (*BillingHistory) Size

func (m *BillingHistory) Size() (n int)

func (*BillingHistory) String

func (m *BillingHistory) String() string

func (*BillingHistory) Unmarshal

func (m *BillingHistory) Unmarshal(dAtA []byte) error

func (*BillingHistory) XXX_DiscardUnknown

func (m *BillingHistory) XXX_DiscardUnknown()

func (*BillingHistory) XXX_Marshal

func (m *BillingHistory) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*BillingHistory) XXX_Merge

func (m *BillingHistory) XXX_Merge(src proto.Message)

func (*BillingHistory) XXX_Size

func (m *BillingHistory) XXX_Size() int

func (*BillingHistory) XXX_Unmarshal

func (m *BillingHistory) XXX_Unmarshal(b []byte) error

type BillingKeeper

type BillingKeeper interface {
	GetPlatformValidators(ctx sdk.Context) []string
}

type ChainletKeeper

type ChainletKeeper interface {
	ListChainlets(ctx context.Context, req *chainlettypes.QueryListChainletsRequest) (*chainlettypes.QueryListChainletsResponse, error)
	ListChainletStack(ctx context.Context, req *chainlettypes.QueryListChainletStackRequest) (*chainlettypes.QueryListChainletStackResponse, error)
	StopChainlet(ctx sdk.Context, chainId string) error
	GetChainlet(ctx context.Context, req *chainlettypes.QueryGetChainletRequest) (*chainlettypes.QueryGetChainletResponse, error)
	ChainletExists(ctx sdk.Context, chainId string) bool
	StartExistingChainlet(ctx sdk.Context, chainId string) error
	IsChainletStarted(ctx sdk.Context, chainId string) (bool, error)
	GetChainletStackInfo(ctx sdk.Context, chainId string) (*chainlettypes.ChainletStack, error)
	GetChainletInfo(ctx sdk.Context, chainId string) (*chainlettypes.Chainlet, error)
	GetParams(ctx sdk.Context) chainlettypes.Params
}

type EpochsKeeper

type EpochsKeeper interface {
	GetEpochInfo(ctx sdk.Context, identifier string) epochstypes.EpochInfo
}

type EscrowKeeper

type EscrowKeeper interface {
	BillAccount(ctx sdk.Context, amount sdk.Coin, chainId string, toModule string) error
	GetChainletWithPools(ctx sdk.Context, chainId string) (acc escrowtypes.ChainletAccount, pool []*escrowtypes.DenomPool, err error)
}

type GenesisState

type GenesisState struct {
	Params Params `protobuf:"bytes,1,opt,name=params,proto3" json:"params"`
	// Billing history records
	BillingHistory []SaveBillingHistory `protobuf:"bytes,2,rep,name=billing_history,json=billingHistory,proto3" json:"billing_history"`
	// Validator payout history records
	ValidatorPayoutHistory []ValidatorPayoutHistory `protobuf:"bytes,3,rep,name=validator_payout_history,json=validatorPayoutHistory,proto3" json:"validator_payout_history"`
}

GenesisState defines the billing module's genesis state.

func DefaultGenesis

func DefaultGenesis() *GenesisState

DefaultGenesis returns the default genesis state

func (*GenesisState) Descriptor

func (*GenesisState) Descriptor() ([]byte, []int)

func (*GenesisState) GetBillingHistory

func (m *GenesisState) GetBillingHistory() []SaveBillingHistory

func (*GenesisState) GetParams

func (m *GenesisState) GetParams() Params

func (*GenesisState) GetValidatorPayoutHistory

func (m *GenesisState) GetValidatorPayoutHistory() []ValidatorPayoutHistory

func (*GenesisState) Marshal

func (m *GenesisState) Marshal() (dAtA []byte, err error)

func (*GenesisState) MarshalTo

func (m *GenesisState) MarshalTo(dAtA []byte) (int, error)

func (*GenesisState) MarshalToSizedBuffer

func (m *GenesisState) MarshalToSizedBuffer(dAtA []byte) (int, error)

func (*GenesisState) ProtoMessage

func (*GenesisState) ProtoMessage()

func (*GenesisState) Reset

func (m *GenesisState) Reset()

func (*GenesisState) Size

func (m *GenesisState) Size() (n int)

func (*GenesisState) String

func (m *GenesisState) String() string

func (*GenesisState) Unmarshal

func (m *GenesisState) Unmarshal(dAtA []byte) error

func (GenesisState) Validate

func (gs GenesisState) Validate() error

Validate performs basic genesis state validation returning an error upon any failure.

func (*GenesisState) XXX_DiscardUnknown

func (m *GenesisState) XXX_DiscardUnknown()

func (*GenesisState) XXX_Marshal

func (m *GenesisState) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*GenesisState) XXX_Merge

func (m *GenesisState) XXX_Merge(src proto.Message)

func (*GenesisState) XXX_Size

func (m *GenesisState) XXX_Size() int

func (*GenesisState) XXX_Unmarshal

func (m *GenesisState) XXX_Unmarshal(b []byte) error

type MsgClient

type MsgClient interface {
	// this line is used by starport scaffolding # proto/tx/rpc
	SetPlatformValidators(ctx context.Context, in *MsgSetPlatformValidators, opts ...grpc.CallOption) (*MsgSetPlatformValidatorsResponse, error)
}

MsgClient is the client API for Msg service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.

func NewMsgClient

func NewMsgClient(cc grpc1.ClientConn) MsgClient

type MsgServer

type MsgServer interface {
	// this line is used by starport scaffolding # proto/tx/rpc
	SetPlatformValidators(context.Context, *MsgSetPlatformValidators) (*MsgSetPlatformValidatorsResponse, error)
}

MsgServer is the server API for Msg service.

type MsgSetPlatformValidators

type MsgSetPlatformValidators struct {
	Creator            string   `protobuf:"bytes,1,opt,name=creator,proto3" json:"creator,omitempty"`
	PlatformValidators []string `protobuf:"bytes,2,rep,name=platform_validators,json=platformValidators,proto3" json:"platform_validators,omitempty"`
}

func (*MsgSetPlatformValidators) Descriptor

func (*MsgSetPlatformValidators) Descriptor() ([]byte, []int)

func (*MsgSetPlatformValidators) GetCreator

func (m *MsgSetPlatformValidators) GetCreator() string

func (*MsgSetPlatformValidators) GetPlatformValidators

func (m *MsgSetPlatformValidators) GetPlatformValidators() []string

func (*MsgSetPlatformValidators) Marshal

func (m *MsgSetPlatformValidators) Marshal() (dAtA []byte, err error)

func (*MsgSetPlatformValidators) MarshalTo

func (m *MsgSetPlatformValidators) MarshalTo(dAtA []byte) (int, error)

func (*MsgSetPlatformValidators) MarshalToSizedBuffer

func (m *MsgSetPlatformValidators) MarshalToSizedBuffer(dAtA []byte) (int, error)

func (*MsgSetPlatformValidators) ProtoMessage

func (*MsgSetPlatformValidators) ProtoMessage()

func (*MsgSetPlatformValidators) Reset

func (m *MsgSetPlatformValidators) Reset()

func (*MsgSetPlatformValidators) Size

func (m *MsgSetPlatformValidators) Size() (n int)

func (*MsgSetPlatformValidators) String

func (m *MsgSetPlatformValidators) String() string

func (*MsgSetPlatformValidators) Unmarshal

func (m *MsgSetPlatformValidators) Unmarshal(dAtA []byte) error

func (*MsgSetPlatformValidators) XXX_DiscardUnknown

func (m *MsgSetPlatformValidators) XXX_DiscardUnknown()

func (*MsgSetPlatformValidators) XXX_Marshal

func (m *MsgSetPlatformValidators) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*MsgSetPlatformValidators) XXX_Merge

func (m *MsgSetPlatformValidators) XXX_Merge(src proto.Message)

func (*MsgSetPlatformValidators) XXX_Size

func (m *MsgSetPlatformValidators) XXX_Size() int

func (*MsgSetPlatformValidators) XXX_Unmarshal

func (m *MsgSetPlatformValidators) XXX_Unmarshal(b []byte) error

type MsgSetPlatformValidatorsResponse

type MsgSetPlatformValidatorsResponse struct {
}

func (*MsgSetPlatformValidatorsResponse) Descriptor

func (*MsgSetPlatformValidatorsResponse) Descriptor() ([]byte, []int)

func (*MsgSetPlatformValidatorsResponse) Marshal

func (m *MsgSetPlatformValidatorsResponse) Marshal() (dAtA []byte, err error)

func (*MsgSetPlatformValidatorsResponse) MarshalTo

func (m *MsgSetPlatformValidatorsResponse) MarshalTo(dAtA []byte) (int, error)

func (*MsgSetPlatformValidatorsResponse) MarshalToSizedBuffer

func (m *MsgSetPlatformValidatorsResponse) MarshalToSizedBuffer(dAtA []byte) (int, error)

func (*MsgSetPlatformValidatorsResponse) ProtoMessage

func (*MsgSetPlatformValidatorsResponse) ProtoMessage()

func (*MsgSetPlatformValidatorsResponse) Reset

func (*MsgSetPlatformValidatorsResponse) Size

func (m *MsgSetPlatformValidatorsResponse) Size() (n int)

func (*MsgSetPlatformValidatorsResponse) String

func (*MsgSetPlatformValidatorsResponse) Unmarshal

func (m *MsgSetPlatformValidatorsResponse) Unmarshal(dAtA []byte) error

func (*MsgSetPlatformValidatorsResponse) XXX_DiscardUnknown

func (m *MsgSetPlatformValidatorsResponse) XXX_DiscardUnknown()

func (*MsgSetPlatformValidatorsResponse) XXX_Marshal

func (m *MsgSetPlatformValidatorsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*MsgSetPlatformValidatorsResponse) XXX_Merge

func (*MsgSetPlatformValidatorsResponse) XXX_Size

func (m *MsgSetPlatformValidatorsResponse) XXX_Size() int

func (*MsgSetPlatformValidatorsResponse) XXX_Unmarshal

func (m *MsgSetPlatformValidatorsResponse) XXX_Unmarshal(b []byte) error

type Params

type Params struct {
	ValidatorPayoutEpoch string   `protobuf:"bytes,1,opt,name=validator_payout_epoch,json=validatorPayoutEpoch,proto3" json:"validator_payout_epoch,omitempty"`
	BillingEpoch         string   `protobuf:"bytes,2,opt,name=billing_epoch,json=billingEpoch,proto3" json:"billing_epoch,omitempty"`
	PlatformValidators   []string `protobuf:"bytes,3,rep,name=platform_validators,json=platformValidators,proto3" json:"platform_validators,omitempty"`
}

Params defines the parameters for the module.

func DefaultParams

func DefaultParams() Params

DefaultParams returns a default set of parameters

func NewParams

func NewParams() Params

NewParams creates a new Params instance

func (*Params) Descriptor

func (*Params) Descriptor() ([]byte, []int)

func (*Params) GetBillingEpoch

func (m *Params) GetBillingEpoch() string

func (*Params) GetPlatformValidators

func (m *Params) GetPlatformValidators() []string

func (*Params) GetValidatorPayoutEpoch

func (m *Params) GetValidatorPayoutEpoch() string

func (*Params) Marshal

func (m *Params) Marshal() (dAtA []byte, err error)

func (*Params) MarshalTo

func (m *Params) MarshalTo(dAtA []byte) (int, error)

func (*Params) MarshalToSizedBuffer

func (m *Params) MarshalToSizedBuffer(dAtA []byte) (int, error)

func (*Params) ParamSetPairs

func (p *Params) ParamSetPairs() paramtypes.ParamSetPairs

ParamSetPairs get the params.ParamSet

func (*Params) ProtoMessage

func (*Params) ProtoMessage()

func (*Params) Reset

func (m *Params) Reset()

func (*Params) Size

func (m *Params) Size() (n int)

func (Params) String

func (p Params) String() string

String implements the Stringer interface.

func (*Params) Unmarshal

func (m *Params) Unmarshal(dAtA []byte) error

func (Params) Validate

func (p Params) Validate() error

Validate validates the set of params

func (*Params) XXX_DiscardUnknown

func (m *Params) XXX_DiscardUnknown()

func (*Params) XXX_Marshal

func (m *Params) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*Params) XXX_Merge

func (m *Params) XXX_Merge(src proto.Message)

func (*Params) XXX_Size

func (m *Params) XXX_Size() int

func (*Params) XXX_Unmarshal

func (m *Params) XXX_Unmarshal(b []byte) error

type QueryClient

type QueryClient interface {
	// Parameters queries the parameters of the module.
	Params(ctx context.Context, in *QueryParamsRequest, opts ...grpc.CallOption) (*QueryParamsResponse, error)
	// Queries a list of GetBillingHistory items.
	GetBillingHistory(ctx context.Context, in *QueryGetBillingHistoryRequest, opts ...grpc.CallOption) (*QueryGetBillingHistoryResponse, error)
	// Queries a list of GetValidatorPayoutHistory items.
	GetValidatorPayoutHistory(ctx context.Context, in *QueryGetValidatorPayoutHistoryRequest, opts ...grpc.CallOption) (*QueryGetValidatorPayoutHistoryResponse, error)
}

QueryClient is the client API for Query service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.

func NewQueryClient

func NewQueryClient(cc grpc1.ClientConn) QueryClient

type QueryGetBillingHistoryRequest

type QueryGetBillingHistoryRequest struct {
	ChainId    string             `protobuf:"bytes,1,opt,name=chainId,proto3" json:"chainId,omitempty"`
	Pagination *query.PageRequest `protobuf:"bytes,2,opt,name=pagination,proto3" json:"pagination,omitempty"`
}

func (*QueryGetBillingHistoryRequest) Descriptor

func (*QueryGetBillingHistoryRequest) Descriptor() ([]byte, []int)

func (*QueryGetBillingHistoryRequest) GetChainId

func (m *QueryGetBillingHistoryRequest) GetChainId() string

func (*QueryGetBillingHistoryRequest) GetPagination

func (m *QueryGetBillingHistoryRequest) GetPagination() *query.PageRequest

func (*QueryGetBillingHistoryRequest) Marshal

func (m *QueryGetBillingHistoryRequest) Marshal() (dAtA []byte, err error)

func (*QueryGetBillingHistoryRequest) MarshalTo

func (m *QueryGetBillingHistoryRequest) MarshalTo(dAtA []byte) (int, error)

func (*QueryGetBillingHistoryRequest) MarshalToSizedBuffer

func (m *QueryGetBillingHistoryRequest) MarshalToSizedBuffer(dAtA []byte) (int, error)

func (*QueryGetBillingHistoryRequest) ProtoMessage

func (*QueryGetBillingHistoryRequest) ProtoMessage()

func (*QueryGetBillingHistoryRequest) Reset

func (m *QueryGetBillingHistoryRequest) Reset()

func (*QueryGetBillingHistoryRequest) Size

func (m *QueryGetBillingHistoryRequest) Size() (n int)

func (*QueryGetBillingHistoryRequest) String

func (*QueryGetBillingHistoryRequest) Unmarshal

func (m *QueryGetBillingHistoryRequest) Unmarshal(dAtA []byte) error

func (*QueryGetBillingHistoryRequest) XXX_DiscardUnknown

func (m *QueryGetBillingHistoryRequest) XXX_DiscardUnknown()

func (*QueryGetBillingHistoryRequest) XXX_Marshal

func (m *QueryGetBillingHistoryRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*QueryGetBillingHistoryRequest) XXX_Merge

func (m *QueryGetBillingHistoryRequest) XXX_Merge(src proto.Message)

func (*QueryGetBillingHistoryRequest) XXX_Size

func (m *QueryGetBillingHistoryRequest) XXX_Size() int

func (*QueryGetBillingHistoryRequest) XXX_Unmarshal

func (m *QueryGetBillingHistoryRequest) XXX_Unmarshal(b []byte) error

type QueryGetBillingHistoryResponse

type QueryGetBillingHistoryResponse struct {
	Billhistory []*BillingHistory   `protobuf:"bytes,1,rep,name=billhistory,proto3" json:"billhistory,omitempty"`
	Pagination  *query.PageResponse `protobuf:"bytes,2,opt,name=pagination,proto3" json:"pagination,omitempty"`
}

func (*QueryGetBillingHistoryResponse) Descriptor

func (*QueryGetBillingHistoryResponse) Descriptor() ([]byte, []int)

func (*QueryGetBillingHistoryResponse) GetBillhistory

func (m *QueryGetBillingHistoryResponse) GetBillhistory() []*BillingHistory

func (*QueryGetBillingHistoryResponse) GetPagination

func (*QueryGetBillingHistoryResponse) Marshal

func (m *QueryGetBillingHistoryResponse) Marshal() (dAtA []byte, err error)

func (*QueryGetBillingHistoryResponse) MarshalTo

func (m *QueryGetBillingHistoryResponse) MarshalTo(dAtA []byte) (int, error)

func (*QueryGetBillingHistoryResponse) MarshalToSizedBuffer

func (m *QueryGetBillingHistoryResponse) MarshalToSizedBuffer(dAtA []byte) (int, error)

func (*QueryGetBillingHistoryResponse) ProtoMessage

func (*QueryGetBillingHistoryResponse) ProtoMessage()

func (*QueryGetBillingHistoryResponse) Reset

func (m *QueryGetBillingHistoryResponse) Reset()

func (*QueryGetBillingHistoryResponse) Size

func (m *QueryGetBillingHistoryResponse) Size() (n int)

func (*QueryGetBillingHistoryResponse) String

func (*QueryGetBillingHistoryResponse) Unmarshal

func (m *QueryGetBillingHistoryResponse) Unmarshal(dAtA []byte) error

func (*QueryGetBillingHistoryResponse) XXX_DiscardUnknown

func (m *QueryGetBillingHistoryResponse) XXX_DiscardUnknown()

func (*QueryGetBillingHistoryResponse) XXX_Marshal

func (m *QueryGetBillingHistoryResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*QueryGetBillingHistoryResponse) XXX_Merge

func (m *QueryGetBillingHistoryResponse) XXX_Merge(src proto.Message)

func (*QueryGetBillingHistoryResponse) XXX_Size

func (m *QueryGetBillingHistoryResponse) XXX_Size() int

func (*QueryGetBillingHistoryResponse) XXX_Unmarshal

func (m *QueryGetBillingHistoryResponse) XXX_Unmarshal(b []byte) error

type QueryGetValidatorPayoutHistoryRequest

type QueryGetValidatorPayoutHistoryRequest struct {
	ValidatorAddress string             `protobuf:"bytes,1,opt,name=validatorAddress,proto3" json:"validatorAddress,omitempty"`
	Pagination       *query.PageRequest `protobuf:"bytes,2,opt,name=pagination,proto3" json:"pagination,omitempty"`
}

func (*QueryGetValidatorPayoutHistoryRequest) Descriptor

func (*QueryGetValidatorPayoutHistoryRequest) Descriptor() ([]byte, []int)

func (*QueryGetValidatorPayoutHistoryRequest) GetPagination

func (*QueryGetValidatorPayoutHistoryRequest) GetValidatorAddress

func (m *QueryGetValidatorPayoutHistoryRequest) GetValidatorAddress() string

func (*QueryGetValidatorPayoutHistoryRequest) Marshal

func (m *QueryGetValidatorPayoutHistoryRequest) Marshal() (dAtA []byte, err error)

func (*QueryGetValidatorPayoutHistoryRequest) MarshalTo

func (m *QueryGetValidatorPayoutHistoryRequest) MarshalTo(dAtA []byte) (int, error)

func (*QueryGetValidatorPayoutHistoryRequest) MarshalToSizedBuffer

func (m *QueryGetValidatorPayoutHistoryRequest) MarshalToSizedBuffer(dAtA []byte) (int, error)

func (*QueryGetValidatorPayoutHistoryRequest) ProtoMessage

func (*QueryGetValidatorPayoutHistoryRequest) ProtoMessage()

func (*QueryGetValidatorPayoutHistoryRequest) Reset

func (*QueryGetValidatorPayoutHistoryRequest) Size

func (*QueryGetValidatorPayoutHistoryRequest) String

func (*QueryGetValidatorPayoutHistoryRequest) Unmarshal

func (m *QueryGetValidatorPayoutHistoryRequest) Unmarshal(dAtA []byte) error

func (*QueryGetValidatorPayoutHistoryRequest) XXX_DiscardUnknown

func (m *QueryGetValidatorPayoutHistoryRequest) XXX_DiscardUnknown()

func (*QueryGetValidatorPayoutHistoryRequest) XXX_Marshal

func (m *QueryGetValidatorPayoutHistoryRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*QueryGetValidatorPayoutHistoryRequest) XXX_Merge

func (*QueryGetValidatorPayoutHistoryRequest) XXX_Size

func (*QueryGetValidatorPayoutHistoryRequest) XXX_Unmarshal

func (m *QueryGetValidatorPayoutHistoryRequest) XXX_Unmarshal(b []byte) error

type QueryGetValidatorPayoutHistoryResponse

type QueryGetValidatorPayoutHistoryResponse struct {
	Validatorpayouthistory []*ValidatorPayoutHistory `protobuf:"bytes,1,rep,name=validatorpayouthistory,proto3" json:"validatorpayouthistory,omitempty"`
	Pagination             *query.PageResponse       `protobuf:"bytes,2,opt,name=pagination,proto3" json:"pagination,omitempty"`
}

func (*QueryGetValidatorPayoutHistoryResponse) Descriptor

func (*QueryGetValidatorPayoutHistoryResponse) Descriptor() ([]byte, []int)

func (*QueryGetValidatorPayoutHistoryResponse) GetPagination

func (*QueryGetValidatorPayoutHistoryResponse) GetValidatorpayouthistory

func (m *QueryGetValidatorPayoutHistoryResponse) GetValidatorpayouthistory() []*ValidatorPayoutHistory

func (*QueryGetValidatorPayoutHistoryResponse) Marshal

func (m *QueryGetValidatorPayoutHistoryResponse) Marshal() (dAtA []byte, err error)

func (*QueryGetValidatorPayoutHistoryResponse) MarshalTo

func (m *QueryGetValidatorPayoutHistoryResponse) MarshalTo(dAtA []byte) (int, error)

func (*QueryGetValidatorPayoutHistoryResponse) MarshalToSizedBuffer

func (m *QueryGetValidatorPayoutHistoryResponse) MarshalToSizedBuffer(dAtA []byte) (int, error)

func (*QueryGetValidatorPayoutHistoryResponse) ProtoMessage

func (*QueryGetValidatorPayoutHistoryResponse) Reset

func (*QueryGetValidatorPayoutHistoryResponse) Size

func (*QueryGetValidatorPayoutHistoryResponse) String

func (*QueryGetValidatorPayoutHistoryResponse) Unmarshal

func (m *QueryGetValidatorPayoutHistoryResponse) Unmarshal(dAtA []byte) error

func (*QueryGetValidatorPayoutHistoryResponse) XXX_DiscardUnknown

func (m *QueryGetValidatorPayoutHistoryResponse) XXX_DiscardUnknown()

func (*QueryGetValidatorPayoutHistoryResponse) XXX_Marshal

func (m *QueryGetValidatorPayoutHistoryResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*QueryGetValidatorPayoutHistoryResponse) XXX_Merge

func (*QueryGetValidatorPayoutHistoryResponse) XXX_Size

func (*QueryGetValidatorPayoutHistoryResponse) XXX_Unmarshal

func (m *QueryGetValidatorPayoutHistoryResponse) XXX_Unmarshal(b []byte) error

type QueryParamsRequest

type QueryParamsRequest struct {
}

QueryParamsRequest is request type for the Query/Params RPC method.

func (*QueryParamsRequest) Descriptor

func (*QueryParamsRequest) Descriptor() ([]byte, []int)

func (*QueryParamsRequest) Marshal

func (m *QueryParamsRequest) Marshal() (dAtA []byte, err error)

func (*QueryParamsRequest) MarshalTo

func (m *QueryParamsRequest) MarshalTo(dAtA []byte) (int, error)

func (*QueryParamsRequest) MarshalToSizedBuffer

func (m *QueryParamsRequest) MarshalToSizedBuffer(dAtA []byte) (int, error)

func (*QueryParamsRequest) ProtoMessage

func (*QueryParamsRequest) ProtoMessage()

func (*QueryParamsRequest) Reset

func (m *QueryParamsRequest) Reset()

func (*QueryParamsRequest) Size

func (m *QueryParamsRequest) Size() (n int)

func (*QueryParamsRequest) String

func (m *QueryParamsRequest) String() string

func (*QueryParamsRequest) Unmarshal

func (m *QueryParamsRequest) Unmarshal(dAtA []byte) error

func (*QueryParamsRequest) XXX_DiscardUnknown

func (m *QueryParamsRequest) XXX_DiscardUnknown()

func (*QueryParamsRequest) XXX_Marshal

func (m *QueryParamsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*QueryParamsRequest) XXX_Merge

func (m *QueryParamsRequest) XXX_Merge(src proto.Message)

func (*QueryParamsRequest) XXX_Size

func (m *QueryParamsRequest) XXX_Size() int

func (*QueryParamsRequest) XXX_Unmarshal

func (m *QueryParamsRequest) XXX_Unmarshal(b []byte) error

type QueryParamsResponse

type QueryParamsResponse struct {
	// params holds all the parameters of this module.
	Params Params `protobuf:"bytes,1,opt,name=params,proto3" json:"params"`
}

QueryParamsResponse is response type for the Query/Params RPC method.

func (*QueryParamsResponse) Descriptor

func (*QueryParamsResponse) Descriptor() ([]byte, []int)

func (*QueryParamsResponse) GetParams

func (m *QueryParamsResponse) GetParams() Params

func (*QueryParamsResponse) Marshal

func (m *QueryParamsResponse) Marshal() (dAtA []byte, err error)

func (*QueryParamsResponse) MarshalTo

func (m *QueryParamsResponse) MarshalTo(dAtA []byte) (int, error)

func (*QueryParamsResponse) MarshalToSizedBuffer

func (m *QueryParamsResponse) MarshalToSizedBuffer(dAtA []byte) (int, error)

func (*QueryParamsResponse) ProtoMessage

func (*QueryParamsResponse) ProtoMessage()

func (*QueryParamsResponse) Reset

func (m *QueryParamsResponse) Reset()

func (*QueryParamsResponse) Size

func (m *QueryParamsResponse) Size() (n int)

func (*QueryParamsResponse) String

func (m *QueryParamsResponse) String() string

func (*QueryParamsResponse) Unmarshal

func (m *QueryParamsResponse) Unmarshal(dAtA []byte) error

func (*QueryParamsResponse) XXX_DiscardUnknown

func (m *QueryParamsResponse) XXX_DiscardUnknown()

func (*QueryParamsResponse) XXX_Marshal

func (m *QueryParamsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*QueryParamsResponse) XXX_Merge

func (m *QueryParamsResponse) XXX_Merge(src proto.Message)

func (*QueryParamsResponse) XXX_Size

func (m *QueryParamsResponse) XXX_Size() int

func (*QueryParamsResponse) XXX_Unmarshal

func (m *QueryParamsResponse) XXX_Unmarshal(b []byte) error

type QueryServer

type QueryServer interface {
	// Parameters queries the parameters of the module.
	Params(context.Context, *QueryParamsRequest) (*QueryParamsResponse, error)
	// Queries a list of GetBillingHistory items.
	GetBillingHistory(context.Context, *QueryGetBillingHistoryRequest) (*QueryGetBillingHistoryResponse, error)
	// Queries a list of GetValidatorPayoutHistory items.
	GetValidatorPayoutHistory(context.Context, *QueryGetValidatorPayoutHistoryRequest) (*QueryGetValidatorPayoutHistoryResponse, error)
}

QueryServer is the server API for Query service.

type SaveBillingHistory

type SaveBillingHistory struct {
	ChainletId      string `protobuf:"bytes,1,opt,name=chainletId,proto3" json:"chainletId,omitempty"`
	EpochIdentifier string `protobuf:"bytes,2,opt,name=epochIdentifier,proto3" json:"epochIdentifier,omitempty"`
	EpochNumber     int64  `protobuf:"varint,3,opt,name=epochNumber,proto3" json:"epochNumber,omitempty"`
	BilledAmount    string `protobuf:"bytes,4,opt,name=billedAmount,proto3" json:"billedAmount,omitempty"`
}

func (*SaveBillingHistory) Descriptor

func (*SaveBillingHistory) Descriptor() ([]byte, []int)

func (*SaveBillingHistory) GetBilledAmount

func (m *SaveBillingHistory) GetBilledAmount() string

func (*SaveBillingHistory) GetChainletId

func (m *SaveBillingHistory) GetChainletId() string

func (*SaveBillingHistory) GetEpochIdentifier

func (m *SaveBillingHistory) GetEpochIdentifier() string

func (*SaveBillingHistory) GetEpochNumber

func (m *SaveBillingHistory) GetEpochNumber() int64

func (*SaveBillingHistory) Marshal

func (m *SaveBillingHistory) Marshal() (dAtA []byte, err error)

func (*SaveBillingHistory) MarshalTo

func (m *SaveBillingHistory) MarshalTo(dAtA []byte) (int, error)

func (*SaveBillingHistory) MarshalToSizedBuffer

func (m *SaveBillingHistory) MarshalToSizedBuffer(dAtA []byte) (int, error)

func (*SaveBillingHistory) ProtoMessage

func (*SaveBillingHistory) ProtoMessage()

func (*SaveBillingHistory) Reset

func (m *SaveBillingHistory) Reset()

func (*SaveBillingHistory) Size

func (m *SaveBillingHistory) Size() (n int)

func (*SaveBillingHistory) String

func (m *SaveBillingHistory) String() string

func (*SaveBillingHistory) Unmarshal

func (m *SaveBillingHistory) Unmarshal(dAtA []byte) error

func (*SaveBillingHistory) XXX_DiscardUnknown

func (m *SaveBillingHistory) XXX_DiscardUnknown()

func (*SaveBillingHistory) XXX_Marshal

func (m *SaveBillingHistory) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*SaveBillingHistory) XXX_Merge

func (m *SaveBillingHistory) XXX_Merge(src proto.Message)

func (*SaveBillingHistory) XXX_Size

func (m *SaveBillingHistory) XXX_Size() int

func (*SaveBillingHistory) XXX_Unmarshal

func (m *SaveBillingHistory) XXX_Unmarshal(b []byte) error

type StakingKeeper

type StakingKeeper interface {
	GetValidators(ctx context.Context, maxRetrieve uint32) (validators []stakingtypes.Validator, err error)
}

type UnimplementedMsgServer

type UnimplementedMsgServer struct {
}

UnimplementedMsgServer can be embedded to have forward compatible implementations.

func (*UnimplementedMsgServer) SetPlatformValidators

type UnimplementedQueryServer

type UnimplementedQueryServer struct {
}

UnimplementedQueryServer can be embedded to have forward compatible implementations.

func (*UnimplementedQueryServer) GetBillingHistory

func (*UnimplementedQueryServer) Params

type ValidatorPayoutHistory

type ValidatorPayoutHistory struct {
	ValidatorAddress string `protobuf:"bytes,1,opt,name=validatorAddress,proto3" json:"validatorAddress,omitempty"`
	EpochIdentifier  string `protobuf:"bytes,2,opt,name=epochIdentifier,proto3" json:"epochIdentifier,omitempty"`
	EpochNumber      int64  `protobuf:"varint,3,opt,name=epochNumber,proto3" json:"epochNumber,omitempty"`
	EpochStartTime   string `protobuf:"bytes,4,opt,name=epochStartTime,proto3" json:"epochStartTime,omitempty"`
	RewardAmount     string `protobuf:"bytes,5,opt,name=rewardAmount,proto3" json:"rewardAmount,omitempty"`
}

func (*ValidatorPayoutHistory) Descriptor

func (*ValidatorPayoutHistory) Descriptor() ([]byte, []int)

func (*ValidatorPayoutHistory) GetEpochIdentifier

func (m *ValidatorPayoutHistory) GetEpochIdentifier() string

func (*ValidatorPayoutHistory) GetEpochNumber

func (m *ValidatorPayoutHistory) GetEpochNumber() int64

func (*ValidatorPayoutHistory) GetEpochStartTime

func (m *ValidatorPayoutHistory) GetEpochStartTime() string

func (*ValidatorPayoutHistory) GetRewardAmount

func (m *ValidatorPayoutHistory) GetRewardAmount() string

func (*ValidatorPayoutHistory) GetValidatorAddress

func (m *ValidatorPayoutHistory) GetValidatorAddress() string

func (*ValidatorPayoutHistory) Marshal

func (m *ValidatorPayoutHistory) Marshal() (dAtA []byte, err error)

func (*ValidatorPayoutHistory) MarshalTo

func (m *ValidatorPayoutHistory) MarshalTo(dAtA []byte) (int, error)

func (*ValidatorPayoutHistory) MarshalToSizedBuffer

func (m *ValidatorPayoutHistory) MarshalToSizedBuffer(dAtA []byte) (int, error)

func (*ValidatorPayoutHistory) ProtoMessage

func (*ValidatorPayoutHistory) ProtoMessage()

func (*ValidatorPayoutHistory) Reset

func (m *ValidatorPayoutHistory) Reset()

func (*ValidatorPayoutHistory) Size

func (m *ValidatorPayoutHistory) Size() (n int)

func (*ValidatorPayoutHistory) String

func (m *ValidatorPayoutHistory) String() string

func (*ValidatorPayoutHistory) Unmarshal

func (m *ValidatorPayoutHistory) Unmarshal(dAtA []byte) error

func (*ValidatorPayoutHistory) XXX_DiscardUnknown

func (m *ValidatorPayoutHistory) XXX_DiscardUnknown()

func (*ValidatorPayoutHistory) XXX_Marshal

func (m *ValidatorPayoutHistory) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*ValidatorPayoutHistory) XXX_Merge

func (m *ValidatorPayoutHistory) XXX_Merge(src proto.Message)

func (*ValidatorPayoutHistory) XXX_Size

func (m *ValidatorPayoutHistory) XXX_Size() int

func (*ValidatorPayoutHistory) XXX_Unmarshal

func (m *ValidatorPayoutHistory) XXX_Unmarshal(b []byte) error

Jump to